@@ -59,6 +59,9 @@ class AutocompleteProvider(object):
         self.ref_types['citations'].append(('\\citeauthor*', _('Cite \'{label}\' (author detailed)'), _('Citation (author detailed)')))
         self.ref_types['citations'].append(('\\citeyear', _('Cite \'{label}\' (year)'), _('Citation (year)')))
         self.ref_types['citations'].append(('\\citeyearpar', _('Cite \'{label}\' (year with brackets)'), _('Citation (year with brackets)')))
+        self.ref_types['citations'].append(('\\textcite', _('Cite \'{label}\' (BibLaTeX)'), _('BibLaTeX citation')))
+        self.ref_types['citations'].append(('\\parencite', _('Cite \'{label}\' (BibLaTeX, with brackets)'), _('BibLaTeX citation (with brackets)')))
+        self.ref_types['citations'].append(('\\autocite', _('Cite \'{label}\' (BibLaTeX)'), _('BibLaTeX citation')))
         self.ref_types['usepackage'] = list()
         self.ref_types['usepackage'].append(('\\usepackage',))
 
@@ -106,6 +109,7 @@ class AutocompleteProvider(object):
                     items.append(item)
         return items
 
+    #@timer.timer
     def get_items(self, word):
         items = list()
         try: static_items = self.static_proposals[word.lower()]
@@ -116,9 +120,13 @@ class AutocompleteProvider(object):
             if add_dynamic and len(dynamic_items) > 0 and dynamic_items[0]['command'].lower() < item['command'].lower():
                 add_dynamic = False
                 items += dynamic_items
-            items.append(item)
+            if not item['lowpriority']:
+                items.append(item)
         if add_dynamic:
             items += dynamic_items
+        for item in static_items:
+            if item['lowpriority']:
+                items.append(item)
         return items
 
     def get_dynamic_items(self, word):
