@@ -50,7 +50,7 @@ class IncludeLaTeXFile(Dialog):
         self.view.pathtype_info_button.set_active(False)
 
         self.view.create_button.set_sensitive(False)
-        self.view.file_chooser_button.unselect_all()
+        self.view.file_chooser_button.reset()
         response = self.view.run()
 
         if response == Gtk.ResponseType.APPLY:
@@ -108,5 +108,6 @@ class IncludeLaTeXFile(Dialog):
     def insert_template(self):
         text = '\\input{' + self.get_display_filename() + '}'
         self.document.insert_text_at_cursor(text)
+        self.document.content.scroll_cursor_onscreen()
 
 
