@@ -34,7 +34,7 @@ class Autocomplete(object):
         self.document_view = document_view
         self.main_window = ServiceLocator.get_main_window()
         self.font_manager = ServiceLocator.get_font_manager()
-        self.font_manager.register_observer(self)
+        self.font_manager.connect('font_string_changed', self.on_font_string_changed)
 
         self.view = view.DocumentAutocompleteView()
         self.mark_start = Gtk.TextMark.new('ac_session_start', True)
@@ -47,10 +47,10 @@ class Autocomplete(object):
         self.blank_session = session_blank.SessionBlank(self, self.document)
         self.session = self.blank_session
 
-        self.shortcuts_bar_height = 37
+        self.shortcutsbar_height = 37
         self.cursor_offset = None
 
-        char_width, line_height = self.font_manager.get_char_dimensions(self.document_view.source_view)
+        char_width, line_height = self.font_manager.get_char_dimensions()
         self.view.scrolled_window.set_max_content_height(5 * line_height)
         self.view.scrolled_window.set_min_content_width(35 * char_width)
 
@@ -61,28 +61,33 @@ class Autocomplete(object):
         self.view.list.connect('row-activated', self.on_row_activated)
         self.view.list.connect('row-selected', self.on_row_selected)
 
-        self.document.register_observer(self)
+        self.document.content.connect('text_inserted', self.on_text_inserted)
+        self.document.content.connect('text_deleted', self.on_text_deleted)
+        self.document.content.connect('buffer_changed', self.on_buffer_changed)
+        self.document.content.connect('insert_mark_set', self.on_insert_mark_set)
+        self.document.content.connect('insert_mark_deleted', self.on_insert_mark_deleted)
 
-    def change_notification(self, change_code, notifying_object, parameter):
+    def on_text_inserted(self, content, parameter):
+        buffer, location_iter, text, text_length = parameter
+        self.session.on_insert_text(buffer, location_iter, text, text_length)
 
-        if change_code == 'text_inserted':
-            buffer, location_iter, text, text_length = parameter
-            self.session.on_insert_text(buffer, location_iter, text, text_length)
+    def on_text_deleted(self, content, parameter):
+        buffer, start_iter, end_iter = parameter
+        self.session.on_delete_range(buffer, start_iter, end_iter)
 
-        if change_code == 'text_deleted':
-            buffer, start_iter, end_iter = parameter
-            self.session.on_delete_range(buffer, start_iter, end_iter)
+    def on_buffer_changed(self, content, buffer):
+        self.update(True)
 
-        if change_code == 'buffer_changed':
-            self.update(True)
+    def on_insert_mark_set(self, content):
+        self.update(False)
 
-        if change_code in ['insert_mark_set', 'insert_mark_deleted']:
-            self.update(False)
+    def on_insert_mark_deleted(self, content):
+        self.update(False)
 
-        if change_code == 'font_string_changed':
-            char_width, line_height = self.font_manager.get_char_dimensions(self.document_view.source_view)
-            self.view.scrolled_window.set_max_content_height(5 * line_height)
-            self.view.scrolled_window.set_min_content_width(35 * char_width)
+    def on_font_string_changed(self, font_manager):
+        char_width, line_height = self.font_manager.get_char_dimensions()
+        self.view.scrolled_window.set_max_content_height(5 * line_height)
+        self.view.scrolled_window.set_min_content_width(35 * char_width)
 
     def on_adjustment_value_changed(self, adjustment, user_data=None):
         self.update_visibility()
@@ -93,7 +98,7 @@ class Autocomplete(object):
         self.submit()
 
     def on_row_selected(self, box, row, user_data=None):
-        char_width, line_height = self.font_manager.get_char_dimensions(self.document_view.source_view)
+        char_width, line_height = self.font_manager.get_char_dimensions()
 
         if row != None:
             command = row.get_child().command
@@ -161,12 +166,11 @@ class Autocomplete(object):
             self.view.select_first()
 
     def position_is_visible(self):
-        line_height = self.font_manager.get_line_height(self.document_view.source_view)
+        line_height = self.font_manager.get_line_height()
 
         height = min(len(self.items), 5) * line_height + 20
 
-        buffer = self.document.get_buffer()
-        insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
+        insert_iter = self.document.content.source_buffer.get_iter_at_mark(self.document.content.source_buffer.get_insert())
         iter_location = self.document_view.source_view.get_iter_location(insert_iter)
         start_iter = insert_iter.copy()
         start_iter.backward_chars(self.session.get_offset())
@@ -184,11 +188,11 @@ class Autocomplete(object):
         full_height = 5 * line_height + 20
 
         if y_position >= line_height - 1 and y_position <= self.document_view.scrolled_window.get_allocated_height() - full_height - line_height:
-            self.view.set_margin_top(y_position + self.shortcuts_bar_height)
+            self.view.set_margin_top(y_position + self.shortcutsbar_height)
         else:
-            self.view.set_margin_top(y_position + self.shortcuts_bar_height - height - line_height)
+            self.view.set_margin_top(y_position + self.shortcutsbar_height - height - line_height)
 
-        char_width, line_height = self.font_manager.get_char_dimensions(self.document_view.source_view)
+        char_width, line_height = self.font_manager.get_char_dimensions()
         width = 25 * char_width
         max_width = 35 * char_width
         while x_position <= self.main_window.preview_paned.get_allocated_width() - width - char_width:
