@@ -19,21 +19,24 @@ import os.path
 import time
 
 from setzer.document.document import Document
+import setzer.document.content.content as content
 import setzer.document.latex.build_system.build_system as build_system
 import setzer.document.latex.build_widget.build_widget as build_widget
 import setzer.document.latex.autocomplete.autocomplete as autocomplete
 import setzer.document.latex.code_folding.code_folding as code_folding
-import setzer.document.latex.parser.latex_parser as latex_parser
 import setzer.document.latex.preview.preview as preview
 import setzer.document.latex.state_manager.state_manager_latex as state_manager_latex
 from setzer.helpers.observable import Observable
-from setzer.app.service_locator import ServiceLocator
 
 
 class DocumentLaTeX(Document):
 
     def __init__(self):
         Document.__init__(self)
+
+        self.content = content.Content('latex')
+        self.init_main_submodules()
+
         self.has_visible_build_system = False
 
         # possible states: idle, ready_for_building
@@ -65,17 +68,6 @@ class DocumentLaTeX(Document):
         self.build_system = build_system.BuildSystem(self)
         self.code_folding = code_folding.CodeFolding(self)
 
-        self.symbols = dict()
-        self.symbols['labels'] = set()
-        self.symbols['included_latex_files'] = set()
-        self.symbols['bibliographies'] = set()
-        self.symbols['bibitems'] = set()
-        self.symbols['packages'] = set()
-        self.symbols['packages_detailed'] = dict()
-        self.symbols['blocks'] = list()
-
-        self.parser = latex_parser.LaTeXParser(self)
-
         self.update_can_sync()
 
     def init_shortcuts(self, shortcuts_manager):
@@ -99,25 +91,26 @@ class DocumentLaTeX(Document):
         shortcuts_manager.main_window.app.set_accels_for_action('win.comment-uncomment', ['<Control>K'])
 
     def get_latex_command_at_cursor(self):
-        return self.source_buffer.get_latex_command_at_cursor()
+        return self.content.get_latex_command_at_cursor()
 
     def get_latex_command_at_cursor_offset(self):
-        return self.source_buffer.get_latex_command_at_cursor_offset()
+        return self.content.get_latex_command_at_cursor_offset()
 
     def replace_latex_command_at_cursor(self, command, dotlabels, is_full_command=False):
-        self.source_buffer.replace_latex_command_at_cursor(command, dotlabels, is_full_command)
+        self.content.replace_latex_command_at_cursor(command, dotlabels, is_full_command)
 
     def add_packages(self, packages):
-        self.get_buffer().add_packages(packages)
+        self.content.add_packages(packages)
+        self.content.scroll_cursor_onscreen()
 
     def get_packages(self):
-        return self.symbols['packages']
+        return self.content.get_packages()
 
     def get_package_details(self):
-        return self.symbols['packages_detailed']
+        return self.content.get_package_details()
 
     def remove_packages(self, packages):
-        self.get_buffer().remove_packages(packages)
+        self.content.remove_packages(packages)
 
     def get_matching_begin_end_offset(self, orig_offset):
         blocks = self.get_blocks()
@@ -129,11 +122,7 @@ class DocumentLaTeX(Document):
         return None
 
     def get_blocks(self):
-        return self.symbols['blocks']
-
-    def set_blocks(self, blocks):
-        self.symbols['blocks'] = blocks
-        self.add_change_code('blocks_changed')
+        return self.content.get_blocks()
 
     def set_build_log_items(self, log_items):
         build_log_items = list()
@@ -180,16 +169,28 @@ class DocumentLaTeX(Document):
         return self.get_included_latex_files() | self.get_bibliography_files()
 
     def get_included_latex_files(self):
-        return self.symbols['included_latex_files']
+        dirname = self.get_dirname()
+
+        filenames = set()
+        for filename in self.content.get_included_latex_files():
+            filenames |= {os.path.normpath(os.path.join(dirname, filename))}
+
+        return filenames
 
     def get_bibliography_files(self):
-        return self.symbols['bibliographies']
+        dirname = self.get_dirname()
+
+        filenames = set()
+        for filename in self.content.get_included_latex_files():
+            filenames |= {os.path.normpath(os.path.join(dirname, filename))}
+
+        return filenames
 
     def get_bibitems(self):
-        return self.symbols['bibitems']
+        return self.content.get_bibitems()
 
     def get_labels(self):
-        return self.symbols['labels']
+        return self.content.get_labels()
 
     def change_build_state(self, state):
         self.build_state = state
@@ -231,11 +232,10 @@ class DocumentLaTeX(Document):
         self.add_change_code('can_sync_changed', self.can_sync)
 
     def forward_sync(self, document):
-        insert = document.source_buffer.get_iter_at_mark(document.source_buffer.get_insert())
         self.forward_sync_arguments = dict()
-        self.forward_sync_arguments['filename'] = document.get_filename()
-        self.forward_sync_arguments['line'] = insert.get_line() + 1
-        self.forward_sync_arguments['line_offset'] = insert.get_line_offset() + 1
+        self.forward_sync_arguments['filename'] = self.get_filename()
+        self.forward_sync_arguments['line'] = self.content.get_cursor_line_number() + 1
+        self.forward_sync_arguments['line_offset'] = self.content.get_cursor_line_offset() + 1
         if self.can_sync:
             self.set_build_mode('forward_sync')
             self.start_building()
@@ -247,15 +247,12 @@ class DocumentLaTeX(Document):
             self.start_building()
 
     def build_and_forward_sync(self):
-        document = ServiceLocator.get_workspace().active_document
-        if document != None:
-            insert = document.source_buffer.get_iter_at_mark(document.source_buffer.get_insert())
-            self.forward_sync_arguments = dict()
-            self.forward_sync_arguments['filename'] = document.get_filename()
-            self.forward_sync_arguments['line'] = insert.get_line() + 1
-            self.forward_sync_arguments['line_offset'] = insert.get_line_offset() + 1
-            self.set_build_mode('build_and_forward_sync')
-            self.start_building()
+        self.forward_sync_arguments = dict()
+        self.forward_sync_arguments['filename'] = self.get_filename()
+        self.forward_sync_arguments['line'] = self.content.get_cursor_line_number() + 1
+        self.forward_sync_arguments['line_offset'] = self.content.get_cursor_line_offset() + 1
+        self.set_build_mode('build_and_forward_sync')
+        self.start_building()
 
     def start_building(self):
         if self.build_mode == 'forward_sync' and not self.has_synctex_file: return
@@ -289,13 +286,14 @@ class DocumentLaTeX(Document):
             self.add_change_code('build_system_visibility_change', has_visible_build_system)
 
     def comment_uncomment(self):
-        self.get_buffer().comment_uncomment()
+        self.content.comment_uncomment()
 
     def set_invert_pdf(self, invert_pdf):
         self.preview.set_invert_pdf(invert_pdf)
 
     def set_synctex_position(self, position):
-        self.get_buffer().set_synctex_position(position)
+        self.content.set_synctex_position(position)
+        self.content.scroll_cursor_onscreen()
 
     def get_folded_regions(self):
         try:
@@ -316,7 +314,4 @@ class DocumentLaTeX(Document):
     def is_bibtex_document(self):
         return False
 
-    def get_gsv_language_name(self):
-        return 'latex'
-
 
