@@ -19,6 +19,7 @@ import os.path
 import time
 
 from setzer.document.document import Document
+import setzer.document.content.content as content
 import setzer.document.latex_sty.state_manager.state_manager_latex_sty as state_manager_latex_sty
 from setzer.helpers.observable import Observable
 from setzer.app.service_locator import ServiceLocator
@@ -29,6 +30,9 @@ class DocumentLaTeXSty(Document):
     def __init__(self):
         Document.__init__(self)
 
+        self.content = content.Content('latex_sty')
+        self.init_main_submodules()
+
         self.state_manager = state_manager_latex_sty.StateManagerLaTeXSty(self)
 
     def init_shortcuts(self, shortcuts_manager):
@@ -77,7 +81,4 @@ class DocumentLaTeXSty(Document):
     def is_bibtex_document(self):
         return False
 
-    def get_gsv_language_name(self):
-        return 'latex'
-
 
