@@ -17,9 +17,11 @@
 
 import gi
 gi.require_version('Gtk', '3.0')
+gi.require_version('GtkSource', '4')
 from gi.repository import GLib
 from gi.repository import Gdk
 from gi.repository import Gtk
+from gi.repository import GtkSource
 
 from setzer.dialogs.dialog_locator import DialogLocator
 
@@ -28,23 +30,26 @@ class Search(object):
     ''' Control find, find and replace. '''
     
     def __init__(self, document, document_view, search_bar):
-
         self.search_bar = search_bar
         self.search_bar_mode = 'search'
 
         self.document_view = document_view
         self.document = document
 
+        self.search_settings = GtkSource.SearchSettings()
+        self.search_context = GtkSource.SearchContext.new(self.document.content.source_buffer, self.search_settings)
+        self.search_context.set_highlight(True)
+
         self.observe_search_bar()
-        self.observe_shortcuts_bar()
+        self.observe_shortcutsbar()
         self.search_bar.connect('size-allocate', self.on_search_bar_size_allocate)
         self.search_bar.match_counter.connect('size-allocate', self.on_match_counter_size_allocate)
 
-        self.document.register_observer(self)
+        self.document.content.connect('selection_might_have_changed', self.on_selection_might_have_changed)
 
-    def observe_shortcuts_bar(self):
-        self.document_view.shortcuts_bar_bottom.button_find.connect('toggled', self.on_find_button_clicked)
-        self.document_view.shortcuts_bar_bottom.button_find_and_replace.connect('toggled', self.on_find_replace_button_clicked)
+    def observe_shortcutsbar(self):
+        self.document_view.shortcutsbar_bottom.button_find.connect('toggled', self.on_find_button_clicked)
+        self.document_view.shortcutsbar_bottom.button_find_and_replace.connect('toggled', self.on_find_replace_button_clicked)
 
     def observe_search_bar(self):
         self.search_bar.entry.connect('search-changed', self.on_search_entry_changed)
@@ -59,21 +64,17 @@ class Search(object):
         self.search_bar.replace_button.connect('clicked', self.on_replace_button_click)
         self.search_bar.replace_all_button.connect('clicked', self.on_replace_all_button_click)
 
-    def change_notification(self, change_code, notifying_object, parameter):
+    def on_selection_might_have_changed(self, document, has_selection):
+        self.update_replace_button()
 
-        if change_code == 'selection_might_have_changed':
-            self.update_replace_button()
-
-    '''
-    *** signal handlers: search bar
-    '''
-    
     def on_search_close_button_click(self, button_object=None):
         self.on_search_stop()
 
     def on_replace_entry_keypress(self, entry, event):
+        modifiers = Gtk.accelerator_get_default_mod_mask()
+
         if event.keyval == Gdk.keyval_from_name('Escape'):
-            if event.state & Gtk.accelerator_get_default_mod_mask() == 0:
+            if event.state & modifiers == 0:
                 self.on_search_stop()
                 return True
         return False
@@ -85,113 +86,101 @@ class Search(object):
         self.on_search_previous_match()
         
     def on_replace_button_click(self, button_object=None):
-        if self.document.get_buffer() != None:
-            buffer = self.document.get_buffer()
-            search_context = self.document.get_search_context()
-            replacement = self.search_bar.replace_entry.get_text()
-
-            bounds = buffer.get_selection_bounds()
-            if len(bounds) == 2:
-                search_context.replace(*bounds, replacement, -1)
-                self.on_search_next_match()        
+        replacement = self.search_bar.replace_entry.get_text()
+        bounds = self.search_context.get_buffer().get_selection_bounds()
+        if len(bounds) == 2:
+            self.search_context.replace(*bounds, replacement, -1)
+            self.on_search_next_match()
 
     def on_replace_all_button_click(self, button_object=None):
-        if self.document.get_buffer() != None:
-            search_context = self.document.get_search_context()
-            original = self.search_bar.entry.get_text()
-            replacement = self.search_bar.replace_entry.get_text()
-            number_of_occurrences = search_context.get_occurrences_count()
-            
-            if number_of_occurrences > 0:
-                dialog = DialogLocator.get_dialog('replace_confirmation')
-                if dialog.run(original, replacement, number_of_occurrences):
-                    search_context.replace_all(replacement, -1)
+        original = self.search_bar.entry.get_text()
+        replacement = self.search_bar.replace_entry.get_text()
+        number_of_occurrences = self.search_context.get_occurrences_count()
+
+        if number_of_occurrences > 0:
+            dialog = DialogLocator.get_dialog('replace_confirmation')
+            if dialog.run(original, replacement, number_of_occurrences):
+                self.search_context.replace_all(replacement, -1)
 
     def on_search_entry_activate(self, entry=None):
         self.on_search_next_match(entry, True)
         self.document_view.source_view.grab_focus()
 
     def on_search_next_match(self, entry=None, include_current_highlight=False):
-        if self.document.get_buffer() != None:
-            buffer = self.document.get_buffer()
-            search_context = self.document.get_search_context()
-            insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
-            bound_iter = buffer.get_iter_at_mark(buffer.get_selection_bound())
+        buffer = self.search_context.get_buffer()
+        insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
+        bound_iter = buffer.get_iter_at_mark(buffer.get_selection_bound())
 
-            if include_current_highlight:
-                if insert_iter.get_offset() < bound_iter.get_offset(): search_iter = insert_iter
-                else: search_iter = bound_iter
-                result = search_context.forward(search_iter)
-            else:
-                if insert_iter.get_offset() < bound_iter.get_offset(): search_iter = bound_iter
-                else: search_iter = insert_iter
-                result = search_context.forward(search_iter)
+        if include_current_highlight:
+            if insert_iter.get_offset() < bound_iter.get_offset(): search_iter = insert_iter
+            else: search_iter = bound_iter
+            result = self.search_context.forward(search_iter)
+        else:
+            if insert_iter.get_offset() < bound_iter.get_offset(): search_iter = bound_iter
+            else: search_iter = insert_iter
+            result = self.search_context.forward(search_iter)
+
+        if result[0] == True:
+            buffer.select_range(result[2], result[1])
+            self.document.content.scroll_cursor_onscreen()
+            self.set_match_counter(self.search_context.get_occurrence_position(result[1], result[2]), self.search_context.get_occurrences_count())
+        else:
+            search_iter = buffer.get_start_iter()
+            result = self.search_context.forward(search_iter)
 
             if result[0] == True:
                 buffer.select_range(result[2], result[1])
-                self.document.source_buffer.scroll_iter_onscreen(result[1])
-                self.set_match_counter(search_context.get_occurrence_position(result[1], result[2]), search_context.get_occurrences_count())
-            else:
-                search_iter = buffer.get_start_iter()
-                result = search_context.forward(search_iter)
-
-                if result[0] == True:
-                    buffer.select_range(result[2], result[1])
-                    self.document.source_buffer.scroll_iter_onscreen(result[1])
-                    self.set_match_counter(search_context.get_occurrence_position(result[1], result[2]), search_context.get_occurrences_count())
+                self.document.content.scroll_cursor_onscreen()
+                self.set_match_counter(self.search_context.get_occurrence_position(result[1], result[2]), self.search_context.get_occurrences_count())
     
     def on_search_previous_match(self, entry=None):
-        if self.document.get_buffer() != None:
-            buffer = self.document.get_buffer()
-            search_context = self.document.get_search_context()
-            insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
-            bound_iter = buffer.get_iter_at_mark(buffer.get_selection_bound())
-            
-            if insert_iter.get_offset() > bound_iter.get_offset(): search_iter = bound_iter
-            else: search_iter = insert_iter
-            result = search_context.backward(search_iter)
+        buffer = self.search_context.get_buffer()
+        insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
+        bound_iter = buffer.get_iter_at_mark(buffer.get_selection_bound())
+        
+        if insert_iter.get_offset() > bound_iter.get_offset(): search_iter = bound_iter
+        else: search_iter = insert_iter
+        result = self.search_context.backward(search_iter)
+
+        if result[0] == True:
+            buffer.select_range(result[1], result[2])
+            self.document.content.scroll_cursor_onscreen()
+            self.set_match_counter(self.search_context.get_occurrence_position(result[1], result[2]), self.search_context.get_occurrences_count())
+        else:
+            search_iter = buffer.get_end_iter()
+            result = self.search_context.backward(search_iter)
 
             if result[0] == True:
                 buffer.select_range(result[1], result[2])
-                self.document.source_buffer.scroll_iter_onscreen(result[2])
-                self.set_match_counter(search_context.get_occurrence_position(result[1], result[2]), search_context.get_occurrences_count())
-            else:
-                search_iter = buffer.get_end_iter()
-                result = search_context.backward(search_iter)
-
-                if result[0] == True:
-                    buffer.select_range(result[1], result[2])
-                    self.document.source_buffer.scroll_iter_onscreen(result[2])
-                    self.set_match_counter(search_context.get_occurrence_position(result[1], result[2]), search_context.get_occurrences_count())
+                self.document.content.scroll_cursor_onscreen()
+                self.set_match_counter(self.search_context.get_occurrence_position(result[1], result[2]), self.search_context.get_occurrences_count())
     
     def on_search_entry_changed(self, entry):
-        if self.document.get_buffer() != None:
-            search_context = self.document.get_search_context()
-            search_view = self.document_view.search_bar
-            self.document.set_search_text(entry.get_text())
-            search_view.replace_entry.set_text(entry.get_text())
-            
-            # scan buffer, then highlight match
-            if len(entry.get_text()) > 0:
-                buffer = self.document.get_buffer()
-                result = search_context.forward(buffer.get_start_iter())
-                if result[0] == False:
-                    self.set_match_counter(-1, -1)
-                    search_view.entry.get_style_context().add_class('error')
-                    search_view.entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY, 'face-uncertain-symbolic')
-                    search_view.replace_all_button.set_sensitive(False)
-                else:
-                    search_view.entry.get_style_context().remove_class('error')
-                    search_view.entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY, search_view.icon_name)
-                    while search_context.get_occurrences_count() == -1 and result[0] == True:
-                        result = search_context.forward(result[2])
-                    self.on_search_next_match(entry, include_current_highlight=True)
-                    search_view.replace_all_button.set_sensitive(True)
-            else:
+        search_view = self.document_view.search_bar
+        self.search_settings.set_search_text(entry.get_text())
+        search_view.replace_entry.set_text(entry.get_text())
+
+        # scan buffer, then highlight match
+        if len(entry.get_text()) > 0:
+            buffer = self.search_context.get_buffer()
+            result = self.search_context.forward(buffer.get_start_iter())
+            if result[0] == False:
                 self.set_match_counter(-1, -1)
+                search_view.entry.get_style_context().add_class('error')
+                search_view.entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY, 'face-uncertain-symbolic')
+                search_view.replace_all_button.set_sensitive(False)
+            else:
                 search_view.entry.get_style_context().remove_class('error')
                 search_view.entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY, search_view.icon_name)
-                search_view.replace_all_button.set_sensitive(False)
+                while self.search_context.get_occurrences_count() == -1 and result[0] == True:
+                    result = self.search_context.forward(result[2])
+                self.on_search_next_match(entry, include_current_highlight=True)
+                search_view.replace_all_button.set_sensitive(True)
+        else:
+            self.set_match_counter(-1, -1)
+            search_view.entry.get_style_context().remove_class('error')
+            search_view.entry.set_icon_from_icon_name(Gtk.EntryIconPosition.PRIMARY, search_view.icon_name)
+            search_view.replace_all_button.set_sensitive(False)
 
     def update_replace_button(self):
         if self.result_selected():
@@ -207,23 +196,23 @@ class Search(object):
         return False
 
     def on_search_stop(self, entry=None):
-        self.document_view.shortcuts_bar_bottom.button_find_and_replace.set_active(False)
-        self.document_view.shortcuts_bar_bottom.button_find.set_active(False)
+        self.document_view.shortcutsbar_bottom.button_find_and_replace.set_active(False)
+        self.document_view.shortcutsbar_bottom.button_find.set_active(False)
 
     def on_find_button_clicked(self, button_object=None):
         if button_object.get_active() == True:
-            self.document_view.shortcuts_bar_bottom.button_find_and_replace.set_active(False)
+            self.document_view.shortcutsbar_bottom.button_find_and_replace.set_active(False)
             self.show_search_bar()
             self.set_mode_search()
-        elif self.document_view.shortcuts_bar_bottom.button_find_and_replace.get_active() == False:
+        elif self.document_view.shortcutsbar_bottom.button_find_and_replace.get_active() == False:
             self.hide_search_bar()
 
     def on_find_replace_button_clicked(self, button_object=None):
         if button_object.get_active() == True:
-            self.document_view.shortcuts_bar_bottom.button_find.set_active(False)
+            self.document_view.shortcutsbar_bottom.button_find.set_active(False)
             self.show_search_bar()
             self.set_mode_replace()
-        elif self.document_view.shortcuts_bar_bottom.button_find.get_active() == False:
+        elif self.document_view.shortcutsbar_bottom.button_find.get_active() == False:
             self.hide_search_bar()
 
     def on_search_bar_size_allocate(self, search_bar=None, allocation=None):
@@ -286,19 +275,10 @@ class Search(object):
         self.search_bar.replace_wrapper.show_all()
         
     def set_text_current_selection(self):
-        buff = self.document.get_buffer()
-        if buff != None and buff.get_has_selection():
-            bounds = buff.get_selection_bounds()
-            if len(bounds) > 0:
-                if bounds[1].get_offset() - bounds[0].get_offset() <= 100:
-                    selection = buff.get_text(bounds[0], bounds[1], True)
-                else:
-                    end = bounds[0].copy()
-                    end.forward_chars(100)
-                    selection = buff.get_text(bounds[0], end, True)
-                search_bar = self.document_view.search_bar
-                search_bar.entry.set_text(selection)
-                return True
+        selection = self.document.get_selected_text()
+        if selection != None:
+            self.search_bar.entry.set_text(selection)
+            return True
         return False
 
     '''
@@ -310,8 +290,12 @@ class Search(object):
         search_bar.match_counter.set_margin_end(6 + 2*search_bar.next_button.get_allocated_width())
         if total == -1:
             search_bar.match_counter.set_text('')
+            search_bar.prev_button.set_sensitive(False)
+            search_bar.next_button.set_sensitive(False)
         else:
             search_bar.match_counter.set_text(str(match_no) + ' of ' + str(total))
+            search_bar.prev_button.set_sensitive(True)
+            search_bar.next_button.set_sensitive(True)
 
     def on_match_counter_size_allocate(self, widget=None, allocation=None):
         search_bar = self.document_view.search_bar
