@@ -64,6 +64,7 @@ class Actions(object):
         self.show_preferences_action = Gio.SimpleAction.new('show-preferences-dialog', None)
         self.show_about_action = Gio.SimpleAction.new('show-about-dialog', None)
         self.quit_action = Gio.SimpleAction.new('quit', None)
+        self.show_build_log_action = Gio.SimpleAction.new('show-build-log', None)
         self.close_build_log_action = Gio.SimpleAction.new('close-build-log', None)
         sc_default = GLib.Variant.new_boolean(settings.get_value('preferences', 'inline_spellchecking'))
         self.toggle_spellchecking_action = Gio.SimpleAction.new_stateful('toggle-spellchecking', None, sc_default)
@@ -71,7 +72,6 @@ class Actions(object):
         self.spellchecking_action = Gio.SimpleAction.new('spellchecking', None)
         dm_default = GLib.Variant.new_boolean(settings.get_value('preferences', 'prefer_dark_mode'))
         self.toggle_dark_mode_action = Gio.SimpleAction.new_stateful('toggle-dark-mode', None, dm_default)
-        settings.gtksettings.get_default().set_property('gtk-application-prefer-dark-theme', dm_default)
         ip_default = GLib.Variant.new_boolean(settings.get_value('preferences', 'invert_pdf'))
         self.toggle_invert_pdf_action = Gio.SimpleAction.new_stateful('toggle-invert-pdf', None, ip_default)
         self.zoom_out_action = Gio.SimpleAction.new('zoom-out', None)
@@ -110,6 +110,7 @@ class Actions(object):
         main_window.add_action(self.show_preferences_action)
         main_window.add_action(self.show_about_action)
         main_window.add_action(self.quit_action)
+        main_window.add_action(self.show_build_log_action)
         main_window.add_action(self.close_build_log_action)
         main_window.add_action(self.toggle_spellchecking_action)
         main_window.add_action(self.set_spellchecking_language_action)
@@ -151,6 +152,7 @@ class Actions(object):
         self.shortcuts_window_action.connect('activate', self.show_shortcuts_window)
         self.show_preferences_action.connect('activate', self.show_preferences_dialog)
         self.show_about_action.connect('activate', self.show_about_dialog)
+        self.show_build_log_action.connect('activate', self.show_build_log)
         self.close_build_log_action.connect('activate', self.close_build_log)
         self.toggle_spellchecking_action.connect('activate', self.on_spellchecking_toggle_toggled)
         self.set_spellchecking_language_action.connect('activate', self.start_spellchecking_language_dialog)
@@ -163,12 +165,11 @@ class Actions(object):
 
         self.font_manager = ServiceLocator.get_font_manager()
         self.update_zoom_actions()
-        self.workspace.register_observer(self)
-        self.font_manager.register_observer(self)
 
-    '''
-    *** decorators
-    '''
+        self.workspace.connect('document_removed', self.on_document_removed)
+        self.workspace.connect('new_inactive_document', self.on_new_inactive_document)
+        self.workspace.connect('new_active_document', self.on_new_active_document)
+        self.font_manager.connect('font_string_changed', self.on_font_string_changed)
 
     def _assert_has_active_document(original_function):
         def new_function(self, *args, **kwargs):
@@ -176,42 +177,33 @@ class Actions(object):
                 return original_function(self, *args, **kwargs)
         return new_function    
 
-    '''
-    *** notification handlers, get called by observed workspace
-    '''
+    def on_document_removed(self, workspace, document):
+        if self.workspace.active_document == None:
+            self.activate_welcome_screen_mode()
+            self.update_document_actions(None)
+            self.update_save_actions(None)
 
-    def change_notification(self, change_code, notifying_object, parameter):
+    def on_new_inactive_document(self, workspace, document):
+        document.content.disconnect('modified_changed', self.on_modified_changed)
 
-        if change_code == 'document_removed':
-            if self.workspace.active_document == None:
-                self.activate_welcome_screen_mode()
-                self.update_save_actions(None)
+    def on_new_active_document(self, workspace, document):
+        self.activate_document_mode()
+        self.update_document_actions(document)
+        self.update_save_actions(document)
+        document.content.connect('modified_changed', self.on_modified_changed)
 
-        if change_code == 'new_inactive_document':
-            document = parameter
-            document.unregister_observer(self)
+    def on_font_string_changed(self, font_manager):
+        self.update_zoom_actions()
 
-        if change_code == 'new_active_document':
-            document = parameter
-            self.activate_document_mode()
-            self.update_save_actions(document)
-            document.register_observer(self)
-
-        if change_code == 'modified_changed':
-            document = notifying_object
-            self.update_save_actions(document)
-
-        if change_code == 'font_string_changed':
-            self.update_zoom_actions()
+    def on_modified_changed(self, content):
+        self.update_save_actions(self.workspace.active_document)
 
     def activate_welcome_screen_mode(self):
         self.save_all_action.set_enabled(False)
         self.spellchecking_action.set_enabled(False)
         self.add_remove_packages_dialog_action.set_enabled(False)
-        self.set_document_actions_active(False)
 
     def activate_document_mode(self):
-        self.set_document_actions_active(True)
         self.enable_spellchecking_action()
         active_document = self.workspace.get_active_document()
         if active_document.is_latex_document():
@@ -246,7 +238,12 @@ class Actions(object):
         else:
             self.save_all_action.set_enabled(False)
 
-    def set_document_actions_active(self, value):
+    def update_document_actions(self, document):
+        if document != None:
+            value = True
+        else:
+            value = False
+
         self.save_as_action.set_enabled(value)
         self.find_action.set_enabled(value)
         self.find_next_action.set_enabled(value)
@@ -255,6 +252,12 @@ class Actions(object):
         self.close_document_action.set_enabled(value)
         self.close_all_action.set_enabled(value)
         self.save_session_action.set_enabled(value)
+
+        if document != None and document.is_latex_document():
+            value = True
+        else:
+            value = False
+
         self.insert_before_after_action.set_enabled(value)
         self.insert_symbol_action.set_enabled(value)
         self.insert_before_document_end_action.set_enabled(value)
@@ -263,6 +266,8 @@ class Actions(object):
         self.add_packages_action.set_enabled(value)
         self.comment_uncomment_action.set_enabled(value)
         self.document_wizard_action.set_enabled(value)
+        self.show_build_log_action.set_enabled(value)
+        self.close_build_log_action.set_enabled(value)
 
     def on_new_latex_document_action_activated(self, action=None, parameter=None):
         self.workspace.create_latex_document(activate=True)
@@ -346,10 +351,10 @@ class Actions(object):
     @_assert_has_active_document
     def on_menu_find_clicked(self, action=None, parameter=None):
         active_document = self.workspace.get_active_document()
-        if active_document.view.shortcuts_bar_bottom.button_find.get_active():
+        if active_document.view.shortcutsbar_bottom.button_find.get_active():
             GLib.idle_add(active_document.search.search_entry_grab_focus, None)
         else:
-            active_document.view.shortcuts_bar_bottom.button_find.set_active(True)
+            active_document.view.shortcutsbar_bottom.button_find.set_active(True)
 
     @_assert_has_active_document
     def find_next(self, action=None, parameter=None):
@@ -366,10 +371,10 @@ class Actions(object):
     @_assert_has_active_document
     def on_menu_find_replace_clicked(self, action=None, parameter=None):
         active_document = self.workspace.get_active_document()
-        if active_document.view.shortcuts_bar_bottom.button_find_and_replace.get_active():
+        if active_document.view.shortcutsbar_bottom.button_find_and_replace.get_active():
             GLib.idle_add(active_document.search.search_entry_grab_focus, None)
         else:
-            active_document.view.shortcuts_bar_bottom.button_find_and_replace.set_active(True)
+            active_document.view.shortcutsbar_bottom.button_find_and_replace.set_active(True)
 
     @_assert_has_active_document
     def on_close_all_clicked(self, action=None, parameter=None):
@@ -395,16 +400,19 @@ class Actions(object):
 
     @_assert_has_active_document
     def insert_before_after(self, action, parameter):
-        active_document = self.workspace.get_active_document().insert_before_after(parameter[0], parameter[1])
+        self.workspace.get_active_document().insert_before_after(parameter[0], parameter[1])
+        self.workspace.get_active_document().content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def insert_symbol(self, action, parameter):
         self.workspace.get_active_document().insert_text_at_cursor(parameter[0])
+        self.workspace.get_active_document().content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def insert_before_document_end(self, action, parameter):
         document = self.workspace.get_active_document()
         document.insert_before_document_end(parameter[0])
+        document.content.scroll_cursor_onscreen()
 
     @_assert_has_active_document
     def start_wizard(self, action, parameter=None):
@@ -462,9 +470,12 @@ class Actions(object):
     def show_about_dialog(self, action, parameter=''):
         DialogLocator.get_dialog('about').run()
 
+    def show_build_log(self, action, parameter=''):
+        self.workspace.set_show_build_log(True)
+
     def close_build_log(self, action, parameter=''):
         self.workspace.set_show_build_log(False)
-        
+    
     def on_spellchecking_toggle_toggled(self, action, parameter=None):
         new_state = not action.get_state().get_boolean()
         action.set_state(GLib.Variant.new_boolean(new_state))
