@@ -49,8 +49,9 @@ class DocumentChooser(Gtk.Popover):
         self.not_found_slate.get_style_context().add_class('not_found')
         self.not_found_slate.get_style_context().add_class('frame')
         box = Gtk.VBox()
-        pixbuf = Gtk.IconTheme.get_default().load_icon('system-search-symbolic', 64, 0)
-        box.pack_start(Gtk.Image.new_from_pixbuf(pixbuf), True, True, 0)
+        image = Gtk.Image.new_from_icon_name('system-search-symbolic', Gtk.IconSize.MENU)
+        image.set_pixel_size(64)
+        box.pack_start(image, True, True, 0)
         box.pack_start(Gtk.Label(_('No results')), False, False, 0)
         outer_box = Gtk.VBox()
         outer_box.set_center_widget(box)
