@@ -47,10 +47,11 @@ class Shortcuts(object):
         
         c_mask = Gdk.ModifierType.CONTROL_MASK
         s_mask = Gdk.ModifierType.SHIFT_MASK
+        a_mask = Gdk.ModifierType.MOD1_MASK
         m_mask = Gdk.ModifierType.META_MASK
         all_mask = Gdk.ModifierType.MODIFIER_MASK
         flags = Gtk.AccelFlags.MASK
-        
+
         self.accel_group.connect(Gdk.keyval_from_name('o'), c_mask | s_mask, flags, self.shortcut_doc_chooser)
         self.accel_group.connect(Gdk.keyval_from_name('t'), c_mask, flags, self.shortcut_show_open_docs)
         self.accel_group.connect(Gdk.keyval_from_name('F1'), 0, flags, self.shortcut_help)
@@ -58,6 +59,7 @@ class Shortcuts(object):
         self.accel_group.connect(Gdk.keyval_from_name('F9'), 0, flags, self.shortcut_sidebar)
         self.accel_group.connect(Gdk.keyval_from_name('F10'), 0, flags, self.shortcut_preview)
         self.accel_group.connect(Gdk.keyval_from_name('t'), c_mask | s_mask, flags, self.shortcut_switch_document)
+        self.accel_group.connect(Gdk.keyval_from_name('j'), c_mask | a_mask, flags, self.shortcut_forward_sync)
         self.main_window.app.set_accels_for_action('win.new-latex-document', ['<Control>n'])
 
         # zoom
@@ -73,6 +75,7 @@ class Shortcuts(object):
         self.main_window.app.set_accels_for_action('win.open-document-dialog', ['<Control>o'])
         self.main_window.app.set_accels_for_action('win.save-and-build', ['F5'])
         self.main_window.app.set_accels_for_action('win.build', ['F6'])
+        self.main_window.app.set_accels_for_action('win.show-shortcuts-window', ['<Control>question'])
         self.main_window.app.set_accels_for_action('win.save', ['<Control>s'])
         self.main_window.app.set_accels_for_action('win.save-as', ['<Control><Shift>s'])
         self.main_window.app.set_accels_for_action('win.close-active-document', ['<Control>w'])
@@ -96,6 +99,10 @@ class Shortcuts(object):
             toggle.clicked()
         return True
 
+    def shortcut_build_log(self, accel_group=None, window=None, key=None, mask=None):
+        show_build_log = not self.workspace.get_show_build_log()
+        self.workspace.set_show_build_log(show_build_log)
+
     def shortcut_preview(self, accel_group=None, window=None, key=None, mask=None):
         toggle = self.main_window.headerbar.preview_toggle
         if toggle.get_sensitive():
@@ -108,18 +115,15 @@ class Shortcuts(object):
             toggle.clicked()
         return True
 
-    def shortcut_build_log(self, accel_group=None, window=None, key=None, mask=None):
-        toggle = self.main_window.latex_shortcuts_bar.button_build_log.get_child()
-        if toggle.get_sensitive():
-            toggle.clicked()
-        return True
-
     def shortcut_switch_document(self, accel_group=None, window=None, key=None, mask=None):
         self.workspace.switch_to_earliest_open_document()
 
     def shortcut_quotes(self, accel_group=None, window=None, key=None, mask=None):
         active_document = self.workspace.get_active_document()
         if active_document != None and active_document.is_latex_document():
-            self.main_window.latex_shortcuts_bar.quotes_button.set_active(True)
+            self.main_window.latex_shortcutsbar.quotes_button.set_active(True)
+
+    def shortcut_forward_sync(self, accel_group=None, window=None, key=None, mask=None):
+        self.workspace.forward_sync(self.workspace.active_document)
 
 
