@@ -30,6 +30,7 @@ import setzer.workspace.preview_panel.preview_panel_presenter as preview_panel_p
 import setzer.workspace.help_panel.help_panel as help_panel
 import setzer.workspace.welcome_screen.welcome_screen as welcome_screen
 import setzer.workspace.sidebar.sidebar as sidebar
+import setzer.workspace.shortcutsbar.shortcutsbar as shortcutsbar
 import setzer.workspace.build_log.build_log as build_log
 import setzer.workspace.headerbar.headerbar_presenter as headerbar_presenter
 import setzer.workspace.document_chooser.document_chooser as document_chooser
@@ -54,6 +55,10 @@ class Workspace(Observable):
 
         self.active_document = None
 
+        self.can_sync = False
+        self.sync_document = None
+        self.update_sync_document()
+
         self.recently_opened_session_files = dict()
         self.session_file_opened = None
 
@@ -63,7 +68,7 @@ class Workspace(Observable):
         self.dark_mode = self.settings.get_value('preferences', 'prefer_dark_mode')
         self.invert_pdf = self.settings.get_value('preferences', 'invert_pdf')
 
-        self.sidebar = sidebar.Sidebar()
+        self.sidebar = sidebar.Sidebar(self)
         self.welcome_screen = welcome_screen.WelcomeScreen()
         self.show_sidebar = self.settings.get_value('window_state', 'show_sidebar')
         self.sidebar_position = self.settings.get_value('window_state', 'sidebar_paned_position')
@@ -73,6 +78,7 @@ class Workspace(Observable):
         self.build_log = build_log.BuildLog(self)
         self.show_build_log = self.settings.get_value('window_state', 'show_build_log')
         self.build_log_position = self.settings.get_value('window_state', 'build_log_paned_position')
+        self.shortcutsbar = shortcutsbar.Shortcutsbar(self)
         self.shortcuts = shortcuts.Shortcuts(self)
 
     def init_workspace_controller(self):
@@ -191,6 +197,8 @@ class Workspace(Observable):
     def set_active_document(self, document):
         if self.active_document != None:
             self.add_change_code('new_inactive_document', self.active_document)
+            self.update_sync_document()
+            self.set_can_sync()
             previously_active_document = self.active_document
             self.active_document = document
             self.set_has_visible_build_system(previously_active_document)
@@ -201,6 +209,8 @@ class Workspace(Observable):
             self.active_document.set_last_activated(time.time())
             self.set_has_visible_build_system(self.active_document)
             self.add_change_code('new_active_document', document)
+            self.update_sync_document()
+            self.set_can_sync()
             self.active_document.init_shortcuts(self.shortcuts)
             self.set_build_log()
 
@@ -277,8 +287,10 @@ class Workspace(Observable):
                     root_document_filename = None
                 for item in sorted(data['open_documents'].values(), key=lambda val: val['last_activated']):
                     document = self.create_document_from_filename(item['filename'])
-                    if item['filename'] == root_document_filename and document != None:
-                        self.set_one_document_root(document)
+                    if document != None:
+                        document.set_last_activated(item['last_activated'])
+                        if item['filename'] == root_document_filename:
+                            self.set_one_document_root(document)
                 for item in data['recently_opened_documents'].values():
                     self.update_recently_opened_document(item['filename'], item['date'], notify=False)
                 try:
@@ -308,6 +320,7 @@ class Workspace(Observable):
                     root_document_filename = None
                 for item in sorted(data['open_documents'].values(), key=lambda val: val['last_activated']):
                     document = self.create_document_from_filename(item['filename'])
+                    document.set_last_activated(item['last_activated'])
                     if item['filename'] == root_document_filename and document != None:
                         self.set_one_document_root(document)        
             if len(self.open_documents) > 0:
@@ -377,6 +390,8 @@ class Workspace(Observable):
                     document.set_root_state(False, True)
                 self.set_has_visible_build_system(document)
             self.add_change_code('root_state_change', 'one_document')
+            self.update_sync_document()
+            self.set_can_sync()
             self.set_build_log()
 
     def unset_root_document(self):
@@ -386,6 +401,8 @@ class Workspace(Observable):
         self.root_document = None
         self.set_has_visible_build_system(self.active_document)
         self.add_change_code('root_state_change', 'no_root_document')
+        self.update_sync_document()
+        self.set_can_sync()
         self.set_build_log()
 
     def get_root_document(self):
@@ -400,31 +417,63 @@ class Workspace(Observable):
             else:
                 document.set_has_visible_build_system(False)
 
+    def update_sync_document(self):
+        if self.root_document != None:
+            self.set_sync_document(self.root_document)
+        elif self.active_document != None:
+            self.set_sync_document(self.active_document)
+        elif self.sync_document != None:
+            self.sync_document.disconnect('is_root_changed', self.on_is_root_changed)
+            self.sync_document.disconnect('can_sync_changed', self.on_can_sync_changed)
+            self.sync_document = None
+
+    def set_sync_document(self, document):
+        if document != self.sync_document:
+            if self.sync_document != None:
+                self.sync_document.disconnect('is_root_changed', self.on_is_root_changed)
+                self.sync_document.disconnect('can_sync_changed', self.on_can_sync_changed)
+            self.sync_document = document
+            self.sync_document.connect('is_root_changed', self.on_is_root_changed)
+            self.sync_document.connect('can_sync_changed', self.on_can_sync_changed)
+
+    def on_can_sync_changed(self, document, can_sync):
+        self.set_can_sync()
+
+    def on_is_root_changed(self, document, is_root):
+        self.set_can_sync()
+
+    def set_can_sync(self):
+        can_sync = False
+        if self.sync_document != None:
+            if self.sync_document.is_latex_document():
+                if self.sync_document.can_sync:
+                    can_sync = True
+        self.can_sync = can_sync
+        self.add_change_code('update_sync_state')
+
+    def forward_sync(self, active_document=None):
+        if active_document == None: return
+        if self.root_document != None:
+            self.root_document.forward_sync(active_document)
+        else:
+            active_document.forward_sync(active_document)
+
     def set_show_sidebar(self, show_sidebar):
         if show_sidebar != self.show_sidebar:
             self.show_sidebar = show_sidebar
             self.add_change_code('set_show_sidebar', show_sidebar)
 
-    def set_sidebar_position(self, sidebar_position):
-        self.sidebar_position = sidebar_position
-
     def set_show_preview_or_help(self, show_preview, show_help):
         if show_preview != self.show_preview or show_help != self.show_help:
             self.show_preview = show_preview
             self.show_help = show_help
             self.add_change_code('set_show_preview_or_help')
 
-    def set_preview_position(self, preview_position):
-        self.preview_position = preview_position
-
     def set_show_build_log(self, show_build_log):
         if show_build_log != self.show_build_log:
             self.show_build_log = show_build_log
             self.add_change_code('show_build_log_state_change', show_build_log)
 
-    def set_build_log_position(self, build_log_position):
-        self.build_log_position = build_log_position
-
     def get_show_build_log(self):
         if self.show_build_log != None:
             return self.show_build_log
